@@ -1,6 +1,5 @@
-/* $Id: gucharmap-unicode-info.h 1390 2007-12-05 22:05:29Z chpe $ */
 /*
- * Copyright (c) 2004 Noah Levitt
+ * Copyright © 2004 Noah Levitt
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -14,9 +13,13 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
+#if !defined (__GUCHARMAP_GUCHARMAP_H_INSIDE__) && !defined (GUCHARMAP_COMPILATION)
+#error "Only <gucharmap/gucharmap.h> can be included directly."
+#endif
+
 #ifndef GUCHARMAP_UNICODE_INFO_H
 #define GUCHARMAP_UNICODE_INFO_H
 
@@ -24,10 +27,26 @@
 
 G_BEGIN_DECLS
 
+typedef enum {
+  GUCHARMAP_UNICODE_VERSION_UNASSIGNED,
+  GUCHARMAP_UNICODE_VERSION_1_1,
+  GUCHARMAP_UNICODE_VERSION_2_0,
+  GUCHARMAP_UNICODE_VERSION_2_1,
+  GUCHARMAP_UNICODE_VERSION_3_0,
+  GUCHARMAP_UNICODE_VERSION_3_1,
+  GUCHARMAP_UNICODE_VERSION_3_2,
+  GUCHARMAP_UNICODE_VERSION_4_0,
+  GUCHARMAP_UNICODE_VERSION_4_1,
+  GUCHARMAP_UNICODE_VERSION_5_0,
+  GUCHARMAP_UNICODE_VERSION_5_1,
+  GUCHARMAP_UNICODE_VERSION_LATEST = GUCHARMAP_UNICODE_VERSION_5_1 /* private, will move forward with each revision */
+} GucharmapUnicodeVersion;
+
 /* return values are read-only */
 G_CONST_RETURN gchar *  gucharmap_get_unicode_name                (gunichar uc);
 G_CONST_RETURN gchar *  gucharmap_get_unicode_data_name           (gunichar uc);
 gint                    gucharmap_get_unicode_data_name_count     (void);
+GucharmapUnicodeVersion gucharmap_get_unicode_version             (gunichar wc);
 G_CONST_RETURN gchar *  gucharmap_get_unicode_category_name       (gunichar uc);
 gint                    gucharmap_get_unihan_count                (void);
 G_CONST_RETURN gchar *  gucharmap_get_unicode_kDefinition         (gunichar uc);
@@ -38,13 +57,6 @@ G_CONST_RETURN gchar *  gucharmap_get_unicode_kKorean             (gunichar uc);
 G_CONST_RETURN gchar *  gucharmap_get_unicode_kJapaneseKun        (gunichar uc);
 G_CONST_RETURN gchar *  gucharmap_get_unicode_kJapaneseOn         (gunichar uc);
 
-/* A wrapper for g_unicode_canonical_decomposition that also does hangul
- * decomposition. 
- * See http://bugzilla.gnome.org/show_bug.cgi?id=100456
- */
-gunichar *              gucharmap_unicode_canonical_decomposition (gunichar  ch, 
-                                                                   gsize    *result_len);
-
 /* nameslist stuff */
 G_CONST_RETURN gchar ** gucharmap_get_nameslist_stars             (gunichar  wc);
 G_CONST_RETURN gchar ** gucharmap_get_nameslist_equals            (gunichar  wc);
@@ -62,6 +74,11 @@ gboolean                gucharmap_unichar_isgraph                 (gunichar  wc)
 G_CONST_RETURN gchar ** gucharmap_unicode_list_scripts            (void);
 G_CONST_RETURN gchar *  gucharmap_unicode_get_script_for_char     (gunichar wc);
 
+G_CONST_RETURN gchar *  gucharmap_unicode_version_to_string       (GucharmapUnicodeVersion version);
+
+/* doesn't really belong here, but no better place was available */
+gunichar     gucharmap_unicode_get_locale_character (void);
+
 G_END_DECLS
 
 #endif  /* #ifndef GUCHARMAP_UNICODE_INFO_H */
